@@ -22,6 +22,9 @@ function openstack_bootstrap_preprocess_page(&$variables) {
     unset($variables['navbar_classes_array'][$key]);
     $variables['navbar_classes_array'][] = 'navbar-os';
   }
+  if (request_path() == 'map') {
+    $vars['theme_hook_suggestions'][] = 'page__map';
+  }
   drupal_add_css('//netdna.bootstrapcdn.com/font-awesome/4.4.0/css/font-awesome.css', array('type' => 'external'));
 }
 
@@ -264,7 +267,7 @@ function openstack_bootstrap_preprocess_user_profile(&$variables) {
       module_load_include('inc', 'field_group_location', 'field_group_lookup');
       $continents = _continent_get_predefined_list();
       $variables['user_profile']['name'][0] = array(
-        '#markup' => '<h3><a href="">'.$account->name.
+        '#markup' => '<h3><a href="">'.format_username($account).
           ' <span class="ambassador-region">// '.$continents[$region_value].'</span></a></h3>',
       );
     }
